"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const db_1 = require("../utils/db");
const error_1 = require("../utils/error");
const uuid_1 = require("uuid");
class AdRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length > 100) {
            throw new error_1.ValidationError("Nazwa ogłosznia nie może być pusta ani mieć więcej niż 100 znaków");
        }
        if (obj.description.length > 1000) {
            throw new error_1.ValidationError("Treść ogłoszenia nie może być dłuższa niż 1000 znaków");
        }
        if (obj.price < 0 || obj.price > 999999) {
            throw new error_1.ValidationError("Cena musi mieścić się w zakresie 0 - 999999");
        }
        if (!obj.url || obj.url.length > 100) {
            throw new error_1.ValidationError("Link nie może byc ani pusty ani dłuższy 100");
        }
        if (typeof obj.lat !== 'number' || typeof obj.lon !== "number") {
            throw new error_1.ValidationError("Współrzędne muszą być liczbą");
        }
        this.id = obj.id;
        this.name = obj.name;
        this.description = obj.description;
        this.price = obj.price;
        this.url = obj.url;
        this.lat = obj.lat;
        this.lon = obj.lon;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `ads` WHERE id = :id", {
                id: id,
            });
            return results.length === 0 ? null : new AdRecord(results[0]);
        });
    }
    static insert(obj) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!obj.id) {
                obj.id = (0, uuid_1.v4)();
            }
            ;
            yield db_1.pool.execute("INSERT INTO `ads` VALUES (:id, :name, :description, :price, :url, :lat, :lon)", {
                id: obj.id,
                name: obj.name,
                description: obj.description,
                price: obj.price,
                url: obj.url,
                lat: obj.lat,
                lon: obj.lon,
            });
            return obj.id;
        });
    }
    static listAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `ads` ORDER BY `name` DESC");
            console.log(results);
            return results.map(result => {
                const { id, lat, lon, } = result;
                return {
                    id, lat, lon,
                };
            });
        });
    }
    static findAll(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `ads` WHERE `name` LIKE :search", {
                search: `%${name}%`,
            });
            return results.map(result => {
                const { id, lat, lon, } = result;
                return {
                    id, lat, lon,
                };
            });
        });
    }
}
exports.AdRecord = AdRecord;
;
//# sourceMappingURL=ad.record.js.map